Files
RedBear-OS/local/recipes/dev/libclc/source/clang/test/SemaCUDA/implicit-copy.cu
T
vasilito cb424d7448 build: static patch-sanity linter (shift-left the malformed-patch class)
verify-patch-sanity.py validates every active recipe .patch has internally-
consistent hunk line counts — catching the 'malformed patch at line N' failure
at commit/CI/preflight time instead of hours into a cook. This cycle hit that
class three times (qtwaylandscanner, sddm, xwayland), each only discovered when
cookbook tried to apply the patch.

Running it across the repo found 29 latent malformed patches (validated against
GNU patch: e.g. relibc/P3-sysv-ipc reproduces 'malformed patch at line 22').
They were harmless only because they sit in vendored recipes (baked, not re-
applied) — but would fail on any version-bump re-derivation. --fix recounts the
hunk headers (body untouched) and repaired all 29.

Wired into build-preflight.sh (Phase 1.0D) and redbear-ci.yml, with a unit test
(test-patch-sanity.sh). Skips archived/legacy trees and unvalidatable formats
(empty placeholders, bare-@@ git hunks).
2026-08-01 05:13:02 +03:00

52 lines
1.7 KiB
Plaintext

// RUN: %clang_cc1 -std=gnu++11 -triple nvptx64-unknown-unknown -fsyntax-only -verify %s
// RUN: %clang_cc1 -std=gnu++11 -triple nvptx64-unknown-unknown -fcuda-is-device -fsyntax-only -verify %s
struct CopyableH {
const CopyableH& operator=(const CopyableH& x) { return *this; }
};
struct CopyableD {
__attribute__((device)) const CopyableD& operator=(const CopyableD x) { return *this; }
};
struct SimpleH {
CopyableH b;
};
// expected-note@-3 2 {{candidate function (the implicit copy assignment operator) not viable: call to __host__ function from __device__ function}}
// expected-note@-4 2 {{candidate function (the implicit move assignment operator) not viable: call to __host__ function from __device__ function}}
struct SimpleD {
CopyableD b;
};
// expected-note@-3 2 {{candidate function (the implicit copy assignment operator) not viable: call to __device__ function from __host__ function}}
// expected-note@-4 2 {{candidate function (the implicit move assignment operator) not viable: call to __device__ function from __host__ function}}
void foo1hh() {
SimpleH a, b;
a = b;
}
__attribute__((device)) void foo1hd() {
SimpleH a, b;
a = b; // expected-error {{no viable overloaded}}
}
void foo1dh() {
SimpleD a, b;
a = b; // expected-error {{no viable overloaded}}
}
__attribute__((device)) void foo1dd() {
SimpleD a, b;
a = b;
}
void foo2hh(SimpleH &a, SimpleH &b) {
a = b;
}
__attribute__((device)) void foo2hd(SimpleH &a, SimpleH &b) {
a = b; // expected-error {{no viable overloaded}}
}
void foo2dh(SimpleD &a, SimpleD &b) {
a = b; // expected-error {{no viable overloaded}}
}
__attribute__((device)) void foo2dd(SimpleD &a, SimpleD &b) {
a = b;
}